import yaml
import os.path
from argparse import Namespace
from yaml import dump
from yaml import load

_tag = '!{.__name__}'
_path, arg = None, None

def register(cls):
    yaml.add_representer(cls, cls.representer)
    yaml.add_constructor(_tag.format(cls), cls.constructor)
    return cls

@register
class Config(Namespace):
    def __repr__(self):
        return yaml.dump(self)
    def __len__(self):
        return len(self.__dict__)
    def __iter__(self):
        return iter(self.__dict__.items())

    @classmethod
    def representer(cls, dumper, data):
        assert type(data) == cls
        return dumper.represent_mapping(
            _tag.format(cls),
            data.__dict__, 
            flow_style=False
        )

    @classmethod
    def constructor(cls, loader, node):
        result = cls()
        yield result
        mapping = loader.construct_mapping(node)
        result.__dict__ = mapping

def set_path(path):
    global _path, arg
    _path = path
    with open(path, 'r') as f:
        arg = yaml.load(f)

def get_path():
    return _path



from setuptools import setup

with open('README.md', 'r') as f:
    long_description = f.read()

setup(
    name='config-yaml',
    version='0.0.2',
    description='Serialize and deserialize your configurations/arguments to yaml.',
    long_description=long_description,
    long_description_content_type="text/markdown",
    url='https://github.com/vickyliin/config-yaml',
    author='vickyliin',
    author_email='vickyliinn@gmail.com',
    license='MIT',

    classifiers=[
        # How mature is this project? Common values are
        #   3 - Alpha
        #   4 - Beta
        #   5 - Production/Stable
        'Development Status :: 3 - Alpha',

        # Indicate who your project is intended for
        'Intended Audience :: Developers',
	'Intended Audience :: Science/Research',
        'Topic :: Software Development :: Libraries',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: System :: Logging',
        'Topic :: Utilities',
        'Programming Language :: Python :: 3 :: Only'
    ],

    keywords='config yaml argparse serialize experiment',
    py_modules=['configyml'], 
    install_requires=['pyyaml']
)
